@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: BaseFont.pm,v 2.3 2006/08/14 18:11:47 areibens Exp $
+#   $Id: BaseFont.pm,v 2.5 2007/01/04 16:33:20 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::BaseFont;
@@ -46,7 +46,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource );
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.3 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2006/08/14 18:11:47 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.5 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/01/04 16:33:20 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -726,18 +726,32 @@ sub textByStrKern
 
 sub text 
 {
-    my ($self,$text,$size)=@_;
+    my ($self,$text,$size,$ident)=@_;
 
     my $newtext=$self->textByStr($text);
 
     if(defined $size && $self->{-dokern})
     {
         $newtext=$self->textByStrKern($text);
-        return("[ $newtext ] TJ");
+        if(defined($ident) && $ident!=0)
+        {
+	        return("[ $ident $newtext ] TJ");
+        }
+        else
+        {
+	        return("[ $newtext ] TJ");
+        }
     }
     elsif(defined $size)
     {
-        return("[ ($newtext) ] TJ");
+        if(defined($ident) && $ident!=0)
+        {
+	        return("[ $ident ($newtext) ] TJ");
+        }
+        else
+        {
+	        return("[ ($newtext) ] TJ");
+        }
     }
     else
     {
@@ -760,6 +774,12 @@ alfred reibenschuh.
 =head1 HISTORY
 
     $Log: BaseFont.pm,v $
+    Revision 2.5  2007/01/04 16:33:20  areibens
+    fix acro 8 fix
+
+    Revision 2.4  2007/01/04 16:02:28  areibens
+    applied untested fix for acrobat 8 "<ident> TJ" bug
+
     Revision 2.3  2006/08/14 18:11:47  areibens
     fixed wxByGlyph
 
